summaryrefslogtreecommitdiffstats
path: root/kio/kfile/kfiletreebranch.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kio/kfile/kfiletreebranch.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kio/kfile/kfiletreebranch.h')
-rw-r--r--kio/kfile/kfiletreebranch.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/kfile/kfiletreebranch.h b/kio/kfile/kfiletreebranch.h
index 30f5cf47c..03976a8d7 100644
--- a/kio/kfile/kfiletreebranch.h
+++ b/kio/kfile/kfiletreebranch.h
@@ -166,9 +166,9 @@ protected:
public:
/**
* find the according KFileTreeViewItem by an url
*/
- virtual KFileTreeViewItem *findTVIByURL( const KURL& );
+ virtual KFileTreeViewItem *tqfindTVIByURL( const KURL& );
signals:
/**
@@ -213,7 +213,7 @@ private:
KURL::List m_openChildrenURLs;
/* The next two members are used for caching purposes in findTVIByURL. */
KURL m_lastFoundURL;
KFileTreeViewItem *m_lastFoundItem;
@@ -166,9 +166,9 @@ protected:
public:
/**
- * find the according KFileTreeViewItem by an url
+ * tqfind the according KFileTreeViewItem by an url
*/
@@ -213,7 +213,7 @@ private:
KURL::List m_openChildrenURLs;
- /* The next two members are used for caching purposes in findTVIByURL. */
+ /* The next two members are used for caching purposes in tqfindTVIByURL. */
KURL m_lastFoundURL;
KFileTreeViewItem *m_lastFoundItem;